# Generated by Django 3.1.4 on 2020-12-22 17:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("aasrp", "0008_auto_20201123_1322"),
    ]

    operations = [
        migrations.AlterField(
            model_name="aasrprequestcomment",
            name="comment_type",
            field=models.CharField(
                choices=[
                    ("Comment", "SRP Request Comment"),
                    ("Request Information", "SRP Request Additional Information"),
                    ("Reject Reason", "SRP Reject Reason"),
                ],
                default="Comment",
                max_length=19,
            ),
        ),
    ]



# Generated by Django 3.1.3 on 2020-11-09 17:47

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("eveonline", "0012_index_additions"),
        ("aasrp", "0005_auto_20201109_1708"),
    ]

    operations = [
        migrations.AlterField(
            model_name="aasrprequest",
            name="character",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="eveonline.evecharacter",
            ),
        ),
    ]



# coding=utf-8

"""
app config
"""

from django.apps import AppConfig

from aasrp import __version__


class AaSrpConfig(AppConfig):
    """
    application config
    """

    name = "aasrp"
    label = "aasrp"
    verbose_name = "AA Ship Replacement v{}".format(__version__)



# coding=utf-8

"""
Migrate srp data from the built-in SRP module
"""

from django.core.management.base import BaseCommand
from django.utils.crypto import get_random_string

from aasrp.helper.character import get_user_for_character
from aasrp.models import AaSrpLink, AaSrpRequest, AaSrpStatus, AaSrpRequestStatus

from allianceauth.srp.models import SrpFleetMain


def get_input(text):
    """
    wrapped input to enable tz import
    """

    return input(text)


class Command(BaseCommand):
    help = "Migrate srp data from the built-in SRP module"

    def _migrate_srp_data(self) -> None:
        """
        migrate srp data from the built-in SRP module
        :return:
        """

        srp_links_migrated = 0
        srp_links_skipped = 0
        srp_requests_migrated = 0
        srp_requests_skipped = 0

        self.stdout.write("Migrating SRP fleets ...")
        srp_fleets = SrpFleetMain.objects.all()
        for srp_fleet in srp_fleets:

            srp_fleet_name = srp_fleet.fleet_name
            srp_fleet_doctrine = srp_fleet.fleet_doctrine
            srp_fleet_time = srp_fleet.fleet_time
            srp_fleet_commander = srp_fleet.fleet_commander
            srp_fleet_creator = get_user_for_character(character=srp_fleet_commander)
            srp_fleet_aar_link = srp_fleet.fleet_srp_aar_link

            # fix srp status
            srp_fleet_status = AaSrpStatus.ACTIVE
            if srp_fleet.fleet_srp_status == "Completed":
                srp_fleet_status = AaSrpStatus.COMPLETED

            if srp_fleet.fleet_srp_code == "":
                srp_fleet_status = AaSrpStatus.CLOSED

                # also fix the missing SRP code, we need it!
                srp_fleet.fleet_srp_code = get_random_string(
                    length=8
                )  # 8 chars only because old SRP link

            srp_fleet_srp_code = srp_fleet.fleet_srp_code

            self.stdout.write(
                "Migrating SRP fleet {srp_code} ...".format(srp_code=srp_fleet_srp_code)
            )

            try:
                srp_link = AaSrpLink.objects.get(srp_code=srp_fleet_srp_code)

                srp_links_skipped += 1
            except AaSrpLink.DoesNotExist:
                srp_link = AaSrpLink()

                srp_link.srp_name = srp_fleet_name
                srp_link.srp_status = srp_fleet_status
                srp_link.srp_code = srp_fleet_srp_code
                srp_link.fleet_doctrine = srp_fleet_doctrine
                srp_link.aar_link = srp_fleet_aar_link
                srp_link.fleet_time = srp_fleet_time
                srp_link.fleet_commander = srp_fleet_commander
                srp_link.creator = srp_fleet_creator
                srp_link.save()

                # mark migrated SRP link as COMPLETED and save the object
                srp_fleet.fleet_srp_status = "Completed"
                srp_fleet.save()

                srp_links_migrated += 1

                # get the new srp link object
                srp_link = AaSrpLink.objects.get(srp_code=srp_fleet_srp_code)

            self.stdout.write(
                "Migrating SRP requests for SRP fleet {srp_code} ...".format(
                    srp_code=srp_fleet_srp_code
                )
            )
            srp_userrequests = srp_fleet.srpuserrequest_set.all()
            for srp_userrequest in srp_userrequests:
                srp_userrequest_killboard_link = srp_userrequest.killboard_link
                srp_userrequest_additional_info = srp_userrequest.additional_info
                srp_userrequest_payout = srp_userrequest.srp_total_amount
                srp_userrequest_loss_amount = srp_userrequest.kb_total_loss
                srp_userrequest_ship_name = srp_userrequest.srp_ship_name
                srp_userrequest_post_time = srp_userrequest.post_time
                srp_userrequest_request_code = get_random_string(length=16)
                srp_userrequest_character = srp_userrequest.character
                srp_userrequest_creator = get_user_for_character(
                    character=srp_userrequest_character
                )
                srp_userrequest_srp_link = srp_link

                srp_userrequest_status = AaSrpRequestStatus.PENDING
                if srp_userrequest.srp_status == "Approved":
                    srp_userrequest_status = AaSrpRequestStatus.APPROVED

                if srp_userrequest.srp_status == "Rejected":
                    srp_userrequest_status = AaSrpRequestStatus.REJECTED

                try:
                    AaSrpRequest.objects.get(
                        killboard_link=srp_userrequest_killboard_link
                    )

                    srp_requests_skipped += 1
                except AaSrpRequest.DoesNotExist:
                    srp_request = AaSrpRequest()

                    srp_request.killboard_link = srp_userrequest_killboard_link
                    srp_request.additional_info = srp_userrequest_additional_info
                    srp_request.request_status = srp_userrequest_status
                    srp_request.payout_amount = srp_userrequest_payout
                    srp_request.loss_amount = srp_userrequest_loss_amount
                    srp_request.ship_name = srp_userrequest_ship_name
                    srp_request.post_time = srp_userrequest_post_time
                    srp_request.request_code = srp_userrequest_request_code
                    srp_request.character = srp_userrequest_character
                    srp_request.creator = srp_userrequest_creator
                    srp_request.srp_link = srp_userrequest_srp_link
                    srp_request.save()

                    srp_requests_migrated += 1

        self.stdout.write("Migration finished.")

        self.stdout.write(
            "SRP links migrated: {srp_links_migrated}".format(
                srp_links_migrated=srp_links_migrated
            )
        )
        self.stdout.write(
            "SRP links skipped: {srp_links_skipped}".format(
                srp_links_skipped=srp_links_skipped
            )
        )

        self.stdout.write(
            "SRP requests migrated: {srp_requests_migrated}".format(
                srp_requests_migrated=srp_requests_migrated
            )
        )
        self.stdout.write(
            "SRP requests skipped: {srp_requests_skipped}".format(
                srp_requests_skipped=srp_requests_skipped
            )
        )

    def handle(self, *args, **options):
        """
        ask before running ...
        :param args:
        :param options:
        """

        self.stdout.write(
            "Migrating SRP links and requests from the built-in SRP module."
        )
        self.stdout.write(
            self.style.WARNING(
                "Due to the nature of the built-in modules design, "
                "ALL SRP links in the built-in module will be marked as COMPLETED "
                "after their migration so they cannot be migrated again and we "
                "don't end up with duplicates!"
            )
        )

        user_input = get_input("Are you sure you want to proceed? (yes/no)?")

        if user_input == "yes":
            self.stdout.write("Starting migration. Please stand by.")
            self._migrate_srp_data()
            self.stdout.write(self.style.SUCCESS("Migration complete!"))
        else:
            self.stdout.write(self.style.WARNING("Aborted."))



# coding=utf-8

"""
SRP Manager
"""

import requests

from django.contrib.auth.models import User

from aasrp import __user_agent__, __title__
from aasrp.models import AaSrpRequest, AaSrpRequestStatus
from aasrp.utils import LoggerAddTag

from allianceauth.eveonline.providers import provider
from allianceauth.services.hooks import get_extension_logger


logger = LoggerAddTag(get_extension_logger(__name__), __title__)


class AaSrpManager:
    """
    AaSrpManager
    """

    @staticmethod
    def get_kill_id(killboard_link):
        """
        get killmail ID from zKillboard link
        :param killboard_link:
        :return:
        """

        num_set = "0123456789"
        kill_id = "".join([c for c in killboard_link if c in num_set])

        return kill_id

    @staticmethod
    def get_kill_data(kill_id):
        """
        get kill data from zKillboard
        :param kill_id:
        :return:
        """

        url = "https://zkillboard.com/api/killID/{killmail_id}/".format(
            killmail_id=kill_id
        )

        headers = {
            "User-Agent": __user_agent__,
            "Content-Type": "application/json",
        }

        request_result = requests.get(url, headers=headers)
        result = request_result.json()[0]

        if result:
            killmail_id = result["killmail_id"]
            killmail_hash = result["zkb"]["hash"]

            esi_client = provider.client

            esi_killmail = esi_client.Killmails.get_killmails_killmail_id_killmail_hash(
                killmail_id=killmail_id, killmail_hash=killmail_hash
            ).result()
        else:
            raise ValueError("Invalid Kill ID")

        if esi_killmail:
            ship_type = esi_killmail["victim"]["ship_type_id"]
            logger.debug("Ship type for kill ID %s is %s" % (kill_id, ship_type))
            ship_value = result["zkb"]["totalValue"]

            logger.debug(
                "Total loss value for kill id %s is %s" % (kill_id, ship_value)
            )

            victim_id = esi_killmail["victim"]["character_id"]

            return ship_type, ship_value, victim_id

        raise ValueError("Invalid Kill ID or Hash.")

    @staticmethod
    def pending_requests_count_for_user(user: User):
        """
        returns the number of open SRP requests for given user
        or None if user has no permission
        """

        if user.has_perm("aasrp.manage_srp") or user.has_perm(
            "aasrp.manage_srp_requests"
        ):
            return AaSrpRequest.objects.filter(
                request_status=AaSrpRequestStatus.PENDING
            ).count()

        return None



# coding=utf-8

"""
some helper functions
so we don't mess up other files too much
"""

from django.contrib.auth.models import User

from allianceauth.eveonline.models import EveCharacter


def get_formatted_character_name(character: EveCharacter) -> str:
    """
    get character name with alliance and corp ticker
    :param character:
    """

    character_name = character.character_name

    character__corporation_ticker = ""
    if character.corporation_ticker:
        character__corporation_ticker = "[{corporation_ticker}] ".format(
            corporation_ticker=character.corporation_ticker
        )

    character__alliance_ticker = ""
    if character.alliance_ticker:
        character__alliance_ticker = "{alliance_ticker} ".format(
            alliance_ticker=character.alliance_ticker
        )

    character_name_formatted = (
        "{alliance_ticker}{corporation_ticker}{character_name}".format(
            alliance_ticker=character__alliance_ticker,
            corporation_ticker=character__corporation_ticker,
            character_name=character_name,
        )
    )

    return character_name_formatted


def get_main_for_character(character: EveCharacter) -> EveCharacter:
    """
    get themain character for a given eve character
    :param character:
    """

    return character.userprofile.main_character


def get_user_for_character(character: EveCharacter) -> User:
    """
    get the user for a character
    :param character:
    :return:
    """

    return character.userprofile.user



# Generated by Django 3.1.3 on 2020-11-06 12:58

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("aasrp", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="aasrplink",
            name="srp_code",
            field=models.CharField(default="", max_length=16),
        ),
        migrations.AlterField(
            model_name="aasrplink",
            name="srp_status",
            field=models.CharField(
                choices=[
                    ("Active", "Active"),
                    ("Closed", "Closed"),
                    ("Completed", "Completed"),
                ],
                default="Active",
                max_length=9,
            ),
        ),
    ]



# coding=utf-8

"""
some helper functions
so we don't mess up other files too much
"""

from aasrp.models import AaSrpRequestStatus, AaSrpLink, AaSrpRequest, AaSrpStatus

from django.contrib.auth.decorators import login_required, permission_required
from django.urls import reverse
from django.utils.translation import gettext_lazy as _


@login_required
@permission_required(
    "aasrp.basic_access", "aasrp.manage_srp_requests", "aasrp.manage_srp"
)
def get_dashboard_action_icons(request, srp_link: AaSrpLink) -> str:
    """
    getting the action buttons for the dashboard view
    :param request:
    :param srp_link:
    """

    actions = ""

    if srp_link.srp_status == AaSrpStatus.ACTIVE:
        button_request_url = reverse("aasrp:request_srp", args=[srp_link.srp_code])
        actions += (
            '<a href="{btn_link}" '
            'class="btn btn-success btn-sm btn-icon-aasrp" '
            'title="{btn_title}">{btn_icon}</a>'.format(
                btn_link=button_request_url,
                btn_icon='<i class="fas fa-hand-holding-usd"></i>',
                btn_title=_("Request SRP"),
            )
        )

    if request.user.has_perm("aasrp.manage_srp") or request.user.has_perm(
        "aasrp.manage_srp_requests"
    ):
        button_view_url = reverse("aasrp:view_srp_requests", args=[srp_link.srp_code])
        actions += (
            '<a href="{btn_link}" '
            'class="btn btn-primary btn-sm btn-icon-aasrp" '
            'title="{btn_title}">{btn_icon}</a><br>'.format(
                btn_link=button_view_url,
                btn_icon='<i class="fas fa-eye"></i>',
                btn_title=_("View SRP Requests"),
            )
        )

        if srp_link.srp_status != AaSrpStatus.COMPLETED:
            if request.user.has_perm("aasrp.manage_srp"):
                if srp_link.srp_status == AaSrpStatus.ACTIVE:
                    button_edit_url = reverse(
                        "aasrp:edit_srp_link", args=[srp_link.srp_code]
                    )
                    actions += (
                        '<a href="{btn_link}" '
                        'class="btn btn-info btn-sm btn-icon-aasrp" '
                        'title="{btn_title}">{btn_icon}</a>'.format(
                            btn_link=button_edit_url,
                            btn_icon='<i class="far fa-newspaper"></i>',
                            btn_title=_("Add/Edit AAR Link"),
                        )
                    )

                    button_disable_url = reverse(
                        "aasrp:disable_srp_link", args=[srp_link.srp_code]
                    )

                    data_name = srp_link.srp_name + " (" + srp_link.srp_code + ")"

                    actions += (
                        '<a class="btn btn-warning btn-sm btn-icon-aasrp" '
                        'title="{btn_title}" '
                        'data-toggle="modal" '
                        'data-target="#{modal_id}" '
                        'data-url="{data_url}" '
                        'data-name="{data_name}">{btn_icon}</a>'.format(
                            data_url=button_disable_url,
                            data_name=data_name,
                            btn_icon='<i class="fas fa-ban"></i>',
                            btn_title=_("Disable SRP Link"),
                            modal_id="disable-srp-link",
                        )
                    )

                if srp_link.srp_status == AaSrpStatus.CLOSED:
                    button_enable_url = reverse(
                        "aasrp:enable_srp_link", args=[srp_link.srp_code]
                    )

                    data_name = srp_link.srp_name + " (" + srp_link.srp_code + ")"

                    actions += (
                        '<a class="btn btn-success btn-sm btn-icon-aasrp" '
                        'title="{btn_title}" '
                        'data-toggle="modal" '
                        'data-target="#{modal_id}" '
                        'data-url="{data_url}" '
                        'data-name="{data_name}">{btn_icon}</a>'.format(
                            data_url=button_enable_url,
                            data_name=data_name,
                            btn_icon='<i class="fas fa-check"></i>',
                            btn_title=_("Enable SRP Link"),
                            modal_id="enable-srp-link",
                        )
                    )

                button_remove_url = reverse(
                    "aasrp:delete_srp_link", args=[srp_link.srp_code]
                )

                data_name = srp_link.srp_name + " (" + srp_link.srp_code + ")"

                actions += (
                    '<a class="btn btn-danger btn-sm btn-icon-aasrp" '
                    'title="{btn_title}" '
                    'data-toggle="modal" '
                    'data-target="#{modal_id}" '
                    'data-url="{data_url}" '
                    'data-name="{data_name}">{btn_icon}</a>'.format(
                        data_url=button_remove_url,
                        data_name=data_name,
                        btn_icon='<i class="far fa-trash-alt"></i>',
                        btn_title=_("Remove SRP Link"),
                        modal_id="delete-srp-link",
                    )
                )

    return actions


@login_required
@permission_required("aasrp.basic_access")
def get_srp_request_status_icon(request, srp_request: AaSrpRequest) -> str:
    """
    get status icon for srp request
    :param request:
    :param srp_request:
    :return:
    """

    srp_request_status_icon = (
        '<button class="btn btn-warning btn-sm btn-icon-aasrp" '
        'title="{request_status_icon_title}">'
        "{request_status_icon}"
        "</button>".format(
            request_status_icon='<i class="fas fa-clock"></i>',
            request_status_icon_title=_("Pending"),
        )
    )
    if srp_request.request_status == AaSrpRequestStatus.APPROVED:
        srp_request_status_icon = (
            '<button class="btn btn-success btn-sm btn-icon-aasrp" '
            'title="{request_status_icon_title}">'
            "{request_status_icon}"
            "</button>".format(
                request_status_icon='<i class="fas fa-thumbs-up"></i>',
                request_status_icon_title=_("Approved"),
            )
        )

    if srp_request.request_status == AaSrpRequestStatus.REJECTED:
        srp_request_status_icon = (
            '<button class="btn btn-danger btn-sm btn-icon-aasrp" '
            'title="{request_status_icon_title}">'
            "{request_status_icon}"
            "</button>".format(
                request_status_icon='<i class="fas fa-thumbs-down"></i>',
                request_status_icon_title=_("Rejected"),
            )
        )

    return srp_request_status_icon


@login_required
@permission_required("aasrp.manage_srp_requests", "aasrp.manage_srp")
def get_srp_request_action_icons(
    request, srp_link: AaSrpLink, srp_request: AaSrpRequest
) -> str:
    """
    get action icons for srp requests
    :param request:
    :param srp_code:
    :param srp_request:
    """

    actions = ""

    # read details
    button_request_details_url = reverse(
        "aasrp:ajax_srp_request_additional_information",
        args=[srp_link.srp_code, srp_request.request_code],
    )
    actions += (
        '<button data-link="{link}" '
        'data-toggle="modal" '
        'data-target="#srp-link-action-modal" '
        'data-modal-type="modal-interactive" '
        'data-modal-title="{title}" '
        'data-modal-button-cancel="{modal_button_cancel}" '
        'data-modal-button-confirm="{modal_button_confirm}" '
        'class="btn btn-primary btn-sm btn-icon-aasrp" '
        'title="{title}">{icon}</button>'.format(
            link=button_request_details_url,
            icon='<i class="fas fa-info-circle"></i>',
            title=_("SRP Request Details"),
            modal_button_cancel=_("{fa_icon} Close").format(fa_icon=""),
            modal_button_confirm=_("OK"),
        )
    )

    if srp_link.srp_status == AaSrpStatus.ACTIVE:
        # accept
        button_request_accept_url = reverse(
            "aasrp:ajax_srp_request_approve",
            args=[srp_link.srp_code, srp_request.request_code],
        )

        button_request_accept_state = ""
        if srp_request.request_status == AaSrpRequestStatus.APPROVED:
            button_request_accept_state = ' disabled="disabled"'

        actions += (
            '<button data-link="{link}" '
            'data-toggle="modal" '
            'data-target="#srp-link-action-modal" '
            'data-modal-type="modal-action" '
            'data-modal-title="{title}" '
            'data-modal-body="{modal_body}" '
            'data-modal-button-cancel="{modal_button_cancel}" '
            'data-modal-button-confirm="{modal_button_confirm}" '
            'data-modal-button-confirm-classes="{modal_button_confirm_classes}" '
            'class="btn btn-success btn-sm btn-icon-aasrp" '
            'title="{title}"{button_state}>{icon}</button>'.format(
                link=button_request_accept_url,
                icon='<i class="fas fa-check"></i>',
                title=_("Accept SRP Request"),
                modal_body=_("Are you sure you want to accept this SRP request?"),
                modal_button_cancel=_("{fa_icon} Cancel").format(
                    fa_icon="<i class='far fa-hand-paper'></i>"
                ),
                modal_button_confirm=_("{fa_icon} Accept SRP Request").format(
                    fa_icon="<i class='fas fa-check'></i>"
                ),
                modal_button_confirm_classes=_("btn btn-success btn-sm"),
                button_state=button_request_accept_state,
            )
        )

        # reject
        button_request_reject_url = reverse(
            "aasrp:ajax_srp_request_deny",
            args=[srp_link.srp_code, srp_request.request_code],
        )

        button_request_reject_state = ""
        if srp_request.request_status == AaSrpRequestStatus.REJECTED:
            button_request_reject_state = ' disabled="disabled"'

        actions += (
            '<button data-link="{link}" '
            'data-toggle="modal" '
            'data-target="#srp-link-action-modal" '
            'data-modal-type="modal-action" '
            'data-modal-title="{title}" '
            'data-modal-body="{modal_body}" '
            'data-modal-button-cancel="{modal_button_cancel}" '
            'data-modal-button-confirm="{modal_button_confirm}" '
            'data-modal-button-confirm-classes="{modal_button_confirm_classes}" '
            'class="btn btn-warning btn-sm btn-icon-aasrp" '
            'title="{title}"{button_state}>{icon}</button>'.format(
                link=button_request_reject_url,
                icon='<i class="fas fa-ban"></i>',
                title=_("Reject SRP Request"),
                modal_body=_("Are you sure you want to reject this SRP request?"),
                modal_button_cancel=_("{fa_icon} Cancel").format(
                    fa_icon="<i class='far fa-hand-paper'></i>"
                ),
                modal_button_confirm=_("{fa_icon} Reject SRP Request").format(
                    fa_icon="<i class='fas fa-ban'></i>"
                ),
                modal_button_confirm_classes=_("btn btn-warning btn-sm"),
                button_state=button_request_reject_state,
            )
        )

        # delete
        if request.user.has_perm("aasrp.manage_srp"):
            button_request_delete_url = reverse(
                "aasrp:ajax_srp_request_remove",
                args=[srp_link.srp_code, srp_request.request_code],
            )
            actions += (
                '<button data-link="{link}" '
                'data-toggle="modal" '
                'data-target="#srp-link-action-modal" '
                'data-modal-type="modal-action" '
                'data-modal-title="{title}" '
                'data-modal-body="{modal_body}" '
                'data-modal-button-cancel="{modal_button_cancel}" '
                'data-modal-button-confirm="{modal_button_confirm}" '
                'data-modal-button-confirm-classes="{modal_button_confirm_classes}" '
                'class="btn btn-danger btn-sm btn-icon-aasrp" '
                'title="{title}">{icon}</button>'.format(
                    link=button_request_delete_url,
                    icon='<i class="fas fa-trash-alt"></i>',
                    title=_("Remove SRP Request"),
                    modal_body=_("Are you sure you want to remove this SRP request?"),
                    modal_button_cancel=_("{fa_icon} Cancel").format(
                        fa_icon="<i class='far fa-hand-paper'></i>"
                    ),
                    modal_button_confirm=_("{fa_icon} Remove SRP Request").format(
                        fa_icon="<i class='fas fa-trash-alt'></i>"
                    ),
                    modal_button_confirm_classes=_("btn btn-danger btn-sm"),
                )
            )

    return actions



# Generated by Django 3.1.3 on 2020-11-23 13:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("aasrp", "0007_auto_20201123_1017"),
    ]

    operations = [
        migrations.AlterField(
            model_name="aasrprequest",
            name="additional_info",
            field=models.TextField(blank=True, default=""),
        ),
    ]



# Generated by Django 3.1.3 on 2020-11-23 10:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("aasrp", "0006_auto_20201109_1747"),
    ]

    operations = [
        migrations.AlterField(
            model_name="aasrplink",
            name="aar_link",
            field=models.CharField(blank=True, default="", max_length=254),
        ),
    ]



# Generated by Django 3.1.3 on 2020-11-09 17:07

import aasrp.models
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("aasrp", "0003_auto_20201109_1654"),
    ]

    operations = [
        migrations.AddField(
            model_name="aasrplink",
            name="creator",
            field=models.ForeignKey(
                help_text="Who created the SRP link?",
                null=True,
                on_delete=models.SET(aasrp.models.get_sentinel_user),
                to=settings.AUTH_USER_MODEL,
            ),
        ),
    ]
